@@ -3,7 +3,7 @@
 use std::collections::HashMap;
 
 #[global_allocator]
-#[cfg(any(all(target_arch = "wasm32", not(target_feature = "atomics"))))]
+#[cfg(any(all(target_arch = "wasm32", not(target_feature = "atomics")), unix))]
 static A: rlsf::SmallGlobalTlsf = rlsf::SmallGlobalTlsf::INIT;
 
 #[test]
